---
title: <span class="badge object-type-scalar"></span> BitsPerSecondIEC
---
# <span class="badge object-type-scalar"></span> BitsPerSecondIEC

Data rate: bits/sec(IEC)

## Definition

```python
# Data rate: bits/sec(IEC)
BitsPerSecondIEC: typing.Literal["binbps"] = "binbps"
```
